@@ -54,7 +54,7 @@ class AioRedisSessionBackend(ISessionBackend):
     async def set(
         self, key: str, value: dict, exp: Optional[int] = None
     ) -> Optional[str]:
-        return await self.redis.set(key, _dumps(value), exp)
+        return await self.redis.set(key, _dumps(value), expire=exp)
 
     async def delete(self, key: str) -> int:
         return await self.redis.delete(key)
